summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorThomas Müller <thomas.mueller@tmit.eu>2015-06-17 12:04:08 +0200
committerThomas Müller <thomas.mueller@tmit.eu>2015-06-17 12:04:08 +0200
commite6e9370eb6bc9bb77c18fef269b2eb08b2baed36 (patch)
tree111da96e34ffbd39e962de9740aeaba262ffdff5 /lib
parentd2305f25278808d781fc8c44363e83adc7b71b9a (diff)
parent9e506abec3ea2c4031ee9602c892fd14c760343b (diff)
downloadnextcloud-server-e6e9370eb6bc9bb77c18fef269b2eb08b2baed36.tar.gz
nextcloud-server-e6e9370eb6bc9bb77c18fef269b2eb08b2baed36.zip
Merge pull request #16985 from owncloud/fix-public-api-phpdoc
Fix OCP PHPDoc
Diffstat (limited to 'lib')
-rw-r--r--lib/public/iservercontainer.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/public/iservercontainer.php b/lib/public/iservercontainer.php
index 3ba506795df..51bd00c6b6f 100644
--- a/lib/public/iservercontainer.php
+++ b/lib/public/iservercontainer.php
@@ -315,11 +315,11 @@ interface IServerContainer {
/**
* Get the certificate manager for the user
*
* @param \OCP\IUser $user (optional) if not specified the current loggedin user is used
* @return \OCP\ICertificateManager
* @since 8.0.0
*/
- public function getCertificateManager($user = null);
+ public function getCertificateManager($userId = null);
/**
* Create a new event source
@@ -315,11 +315,11 @@ interface IServerContainer {
* Get the certificate manager for the user
*
- * @param \OCP\IUser $user (optional) if not specified the current loggedin user is used
+ * @param string $userId (optional) if not specified the current loggedin user is used
* @return \OCP\ICertificateManager
* @since 8.0.0